pub struct BenchmarkSet { /* private fields */ }Expand description
A collection of benchmarks and the filesystems to run the benchmarks against.
Implementations
Sourceimpl BenchmarkSet
impl BenchmarkSet
pub fn new() -> Self
Sourcepub fn add_benchmark<T, U>(&mut self, benchmark: T, filesystem_config: U)
pub fn add_benchmark<T, U>(&mut self, benchmark: T, filesystem_config: U)
Adds a new benchmark with the filesystem it should be run against to the BenchmarkSet.
Sourcepub async fn run(
&self,
block_device_factory: &dyn BlockDeviceFactory,
filter: &RegexSet,
) -> BenchmarkSetResults
pub async fn run( &self, block_device_factory: &dyn BlockDeviceFactory, filter: &RegexSet, ) -> BenchmarkSetResults
Runs all of the added benchmarks against their configured filesystems. The filesystems will
be brought up on block devices created from block_device_factory.