pub trait Filesystem:
Send
+ Sync
+ BoxedFilesystem {
// Required methods
fn shutdown<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait;
fn benchmark_dir(&self) -> &Path;
}Expand description
A trait representing a mounted filesystem that benchmarks will be run against.
Required Methods
Sourcefn shutdown<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
fn shutdown<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
Cleans up the filesystem after a benchmark has run. Filesystem is unusable after this call.
Sourcefn benchmark_dir(&self) -> &Path
fn benchmark_dir(&self) -> &Path
Path to where the filesystem is located in the current process’s namespace. All benchmark operations should happen within this directory.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".